/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_ZfhFo6jN);
  numBytes += sLine_init(&sLine_Bl4AXA1n);
  numBytes += sLine_init(&sLine_sIDkO21r);
  numBytes += sLine_init(&sLine_qfXxonEZ);
  numBytes += sLine_init(&sLine_YSdc7hoN);
  numBytes += sBiquad_init(&sBiquad_s_qKseYIBf);
  numBytes += sLine_init(&sLine_87ZJY5xQ);
  numBytes += sLine_init(&sLine_aX3IcceL);
  numBytes += sLine_init(&sLine_0gPOkgwn);
  numBytes += sLine_init(&sLine_6AqwVpLK);
  numBytes += sBiquad_init(&sBiquad_s_gmlbhYwd);
  numBytes += sLine_init(&sLine_uBBiKLCN);
  numBytes += sLine_init(&sLine_xB5vVno0);
  numBytes += sLine_init(&sLine_pvldJ8Mm);
  numBytes += sLine_init(&sLine_swy87GB8);
  numBytes += sLine_init(&sLine_xSgZs37u);
  numBytes += sBiquad_init(&sBiquad_s_0xDrQ2X5);
  numBytes += sLine_init(&sLine_Hy83DlQU);
  numBytes += sLine_init(&sLine_mJ1jJWDw);
  numBytes += sLine_init(&sLine_Bs4PUEm6);
  numBytes += sLine_init(&sLine_FxFRunxE);
  numBytes += sLine_init(&sLine_BFtO5Bf4);
  numBytes += sBiquad_init(&sBiquad_s_9b1OTnpN);
  numBytes += sLine_init(&sLine_Hcqo1PaB);
  numBytes += sLine_init(&sLine_0CPRdipH);
  numBytes += sLine_init(&sLine_i06P3QRt);
  numBytes += sLine_init(&sLine_nFlyuYqM);
  numBytes += sBiquad_init(&sBiquad_s_SNoQ1swU);
  numBytes += sLine_init(&sLine_qqkpIn1F);
  numBytes += sLine_init(&sLine_UDG2TRd8);
  numBytes += sLine_init(&sLine_WPQY1JXp);
  numBytes += sLine_init(&sLine_ZVN07b2L);
  numBytes += sLine_init(&sLine_wPcwuVhg);
  numBytes += sBiquad_init(&sBiquad_s_GH9jhsfh);
  numBytes += sLine_init(&sLine_pPkQBfE5);
  numBytes += sPhasor_k_init(&sPhasor_YIKPUnKJ, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_6D6WFjID);
  numBytes += sRPole_init(&sRPole_7NIEVmay);
  numBytes += sRPole_init(&sRPole_fX05wI8B);
  numBytes += sTabhead_init(&sTabhead_Pa10i9on, &hTable_kG9lOzhM);
  numBytes += sTabread_init(&sTabread_qLLU7Igh, &hTable_kG9lOzhM, false);
  numBytes += sTabread_init(&sTabread_PczK9kIV, &hTable_kG9lOzhM, false);
  numBytes += sLine_init(&sLine_uucwG5Vg);
  numBytes += sTabhead_init(&sTabhead_gHWjkpqU, &hTable_CuvInPnX);
  numBytes += sTabread_init(&sTabread_UgvtKgnQ, &hTable_CuvInPnX, false);
  numBytes += sTabread_init(&sTabread_6wVlKQAz, &hTable_CuvInPnX, false);
  numBytes += sLine_init(&sLine_NWpG7kvh);
  numBytes += sTabwrite_init(&sTabwrite_X9hzn2TO, &hTable_CuvInPnX);
  numBytes += sTabwrite_init(&sTabwrite_YoQHommw, &hTable_kG9lOzhM);
  numBytes += sLine_init(&sLine_D6Ko2NkM);
  numBytes += sPhasor_k_init(&sPhasor_eEr52Rvg, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_fZowTnW1);
  numBytes += sRPole_init(&sRPole_UnLcVBqj);
  numBytes += sRPole_init(&sRPole_SKGGuLpU);
  numBytes += sTabhead_init(&sTabhead_GsbXUS1T, &hTable_OpaxfIr3);
  numBytes += sTabread_init(&sTabread_XOknnX1h, &hTable_OpaxfIr3, false);
  numBytes += sTabread_init(&sTabread_o4QrwVOe, &hTable_OpaxfIr3, false);
  numBytes += sLine_init(&sLine_xubY7vwP);
  numBytes += sTabhead_init(&sTabhead_eh6VIlIE, &hTable_IhplWmh2);
  numBytes += sTabread_init(&sTabread_2D3TnJ4k, &hTable_IhplWmh2, false);
  numBytes += sTabread_init(&sTabread_JrHooztB, &hTable_IhplWmh2, false);
  numBytes += sLine_init(&sLine_UZZ1XZZw);
  numBytes += sTabwrite_init(&sTabwrite_ztn4yq5p, &hTable_IhplWmh2);
  numBytes += sTabwrite_init(&sTabwrite_usH4eFT3, &hTable_OpaxfIr3);
  numBytes += sLine_init(&sLine_AbGIgxUB);
  numBytes += sPhasor_k_init(&sPhasor_YeZ3J0ZZ, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_d8JPLfdU);
  numBytes += sRPole_init(&sRPole_JHvQ8X8G);
  numBytes += sRPole_init(&sRPole_ICDiRqi3);
  numBytes += sTabhead_init(&sTabhead_zbGW4Bbl, &hTable_8uICRold);
  numBytes += sTabread_init(&sTabread_ZPJFgbpI, &hTable_8uICRold, false);
  numBytes += sTabread_init(&sTabread_ox5KdVRV, &hTable_8uICRold, false);
  numBytes += sLine_init(&sLine_BUvjM2kG);
  numBytes += sTabhead_init(&sTabhead_hrFzWVQr, &hTable_pKcaIv8I);
  numBytes += sTabread_init(&sTabread_AR8dadSy, &hTable_pKcaIv8I, false);
  numBytes += sTabread_init(&sTabread_M0knVvd5, &hTable_pKcaIv8I, false);
  numBytes += sLine_init(&sLine_2MPwhd00);
  numBytes += sTabwrite_init(&sTabwrite_cq9FxIhG, &hTable_pKcaIv8I);
  numBytes += sTabwrite_init(&sTabwrite_r6u4jebs, &hTable_8uICRold);
  numBytes += cVar_init_f(&cVar_Djpulr68, 0.0f);
  numBytes += cVar_init_f(&cVar_j1yJadUD, 0.0f);
  numBytes += cVar_init_f(&cVar_gUsGRDS7, 0.0f);
  numBytes += cVar_init_f(&cVar_ngGNSCZL, 0.0f);
  numBytes += cSlice_init(&cSlice_WWX4SoSV, 1, -1);
  numBytes += cVar_init_f(&cVar_joOyklcF, 1337.0f);
  numBytes += cVar_init_f(&cVar_JgKVOyRh, 0.0f);
  numBytes += cIf_init(&cIf_SkB6mcrm, false);
  numBytes += cIf_init(&cIf_2gAcgqff, false);
  numBytes += cBinop_init(&cBinop_DS4xxbSr, 0.0f); // __pow
  numBytes += cIf_init(&cIf_kxmK4Olg, false);
  numBytes += cBinop_init(&cBinop_ujbIV6Fx, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_sJjo3nY4, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_9jnJNtJ4, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_sD9eOi4j, 0.0f);
  numBytes += cIf_init(&cIf_PEJdc73R, false);
  numBytes += cIf_init(&cIf_HfyfyaDM, false);
  numBytes += cBinop_init(&cBinop_MP4MC7vD, 0.0f); // __pow
  numBytes += cIf_init(&cIf_dlkUdWOR, false);
  numBytes += cBinop_init(&cBinop_L7ifAmW9, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_eJ1QKofa, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_7SQBNfU2, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_LlXuA8Yz, 0.0f);
  numBytes += cIf_init(&cIf_hJKo1Ao4, false);
  numBytes += cIf_init(&cIf_t9cNNq6Q, false);
  numBytes += cBinop_init(&cBinop_f1pSMiI1, 0.0f); // __pow
  numBytes += cIf_init(&cIf_0MpbyJx9, false);
  numBytes += cBinop_init(&cBinop_cv9QDcpl, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_le4nuK2h, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_zjA9MggL, -15.0f); // __eq
  numBytes += cIf_init(&cIf_THnYrj0w, false);
  numBytes += cSlice_init(&cSlice_0Nu3Rzz9, 1, -1);
  numBytes += cVar_init_f(&cVar_K00DKf2R, 0.0f);
  numBytes += cSlice_init(&cSlice_EkAKc7Zy, 1, -1);
  numBytes += cVar_init_f(&cVar_0pDF8R2L, 0.0f);
  numBytes += cSlice_init(&cSlice_IMJyl29p, 1, -1);
  numBytes += cVar_init_f(&cVar_h7xfPepr, 0.0f);
  numBytes += cSlice_init(&cSlice_vGSCwVpv, 1, -1);
  numBytes += cVar_init_f(&cVar_GsPFBawi, 0.313f);
  numBytes += cBinop_init(&cBinop_TgByK9SX, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_D9QoD2vE, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_DfTnkouB, 0.0f);
  numBytes += cVar_init_f(&cVar_tIs6ieDn, 1337.0f);
  numBytes += cVar_init_f(&cVar_iFm0dYxw, 0.3f);
  numBytes += cBinop_init(&cBinop_3ctELofF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tKsvCKDT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NxvB02cU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dDZGaLjR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uoIRINco, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yUTaYghs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5W0WCRA4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_KNHJOU9N, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_MiOFTi0e, 0.0f);
  numBytes += cVar_init_f(&cVar_04UsaYyL, 1337.0f);
  numBytes += cVar_init_f(&cVar_ifs3dGjz, 0.313f);
  numBytes += cBinop_init(&cBinop_OhPzjnif, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kxH7WFoN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9hH19okp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QCFDDuMQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WnYFHANk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UIGshiny, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_hTLh9lBU, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Y27o4wBt, 0.0f);
  numBytes += cVar_init_f(&cVar_0Rm0lYDa, 1037.0f);
  numBytes += cVar_init_f(&cVar_bwFlUtum, 0.4f);
  numBytes += cBinop_init(&cBinop_El9s3DCX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5WPkB2YK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WvwqG9V5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nElh3BBt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PjiVBfPj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SA5bblYl, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_mPmOimLC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mm7TNZRA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v0FRB8ij, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_q67ejzRe, 1, -1);
  numBytes += cVar_init_f(&cVar_yvLhRkzV, 1337.0f);
  numBytes += cVar_init_f(&cVar_FP4Chxaf, 0.0f);
  numBytes += cIf_init(&cIf_7uivgloj, false);
  numBytes += cIf_init(&cIf_U5qdWlUu, false);
  numBytes += cBinop_init(&cBinop_LjWb8RsY, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ZL1KiD2G, false);
  numBytes += cBinop_init(&cBinop_7s05T9Lq, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_abVfnxVd, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_2daN81Q9, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ccOiNUBO, 0.0f);
  numBytes += cIf_init(&cIf_KVS9f7v7, false);
  numBytes += cIf_init(&cIf_CM3hBLVc, false);
  numBytes += cBinop_init(&cBinop_XO7a0UbI, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Y8hvx49F, false);
  numBytes += cBinop_init(&cBinop_gGC0kjgD, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_NBMfISfy, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_14VeVwlB, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_RkZzwcsi, 0.0f);
  numBytes += cIf_init(&cIf_XaD3P38X, false);
  numBytes += cIf_init(&cIf_tl0uE9yS, false);
  numBytes += cBinop_init(&cBinop_zIiQfyEh, 0.0f); // __pow
  numBytes += cIf_init(&cIf_keTyoCYA, false);
  numBytes += cBinop_init(&cBinop_bTUadL91, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_x5A7zUQN, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_S1VxxopG, -15.0f); // __eq
  numBytes += cIf_init(&cIf_OfOBL9Uz, false);
  numBytes += cSlice_init(&cSlice_hYdQ79Ad, 1, -1);
  numBytes += cVar_init_f(&cVar_ELX8H5tX, 0.0f);
  numBytes += cSlice_init(&cSlice_NIaA3xpH, 1, -1);
  numBytes += cVar_init_f(&cVar_Ff9gBaHX, 0.0f);
  numBytes += cSlice_init(&cSlice_UAZtmTE9, 1, -1);
  numBytes += cVar_init_f(&cVar_ecbia8Pv, 0.0f);
  numBytes += cSlice_init(&cSlice_ELgV1INm, 1, -1);
  numBytes += cVar_init_f(&cVar_afYPBMtv, 0.313f);
  numBytes += cBinop_init(&cBinop_c9mp2AOv, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_UflnVjxn, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_zHVl6Pnf, 0.0f);
  numBytes += cVar_init_f(&cVar_Frd23k9e, 1337.0f);
  numBytes += cVar_init_f(&cVar_dCkjEzyZ, 0.3f);
  numBytes += cBinop_init(&cBinop_3JdKKtUV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MzHpZyZg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xVlPtw6w, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TrdwuWL6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9JLJsYWn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UyQcZ5Cq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_v5G1ZD4k, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_jUxf1zN2, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_gZidi2tQ, 0.0f);
  numBytes += cVar_init_f(&cVar_ERvjzQls, 1337.0f);
  numBytes += cVar_init_f(&cVar_oPHDDV6K, 0.313f);
  numBytes += cBinop_init(&cBinop_jEc5WTkm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4mS1orc1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_j0d2xPfr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Nmx3RZtg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_B4lPJrv9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_s3ta5kis, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_28GNFqzM, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_6QqpBWZy, 0.0f);
  numBytes += cVar_init_f(&cVar_kxATIwzy, 1037.0f);
  numBytes += cVar_init_f(&cVar_G1Yu4qJM, 0.4f);
  numBytes += cBinop_init(&cBinop_bOA1MqsV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iVuftvxL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YjJgPbKD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W3B5fzQc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_byqLvUw5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZIAQdjL5, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_XPuAdlsS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dfvj6u83, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cZsUDC5d, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_GFeVoxbF, 5705.6f);
  numBytes += cVar_init_f(&cVar_RvVSyB5V, 313.3f);
  numBytes += cBinop_init(&cBinop_EXC2qBvP, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_BByxVeGK, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_ZFOspIvm, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_IyzXYRds, 0.0f);
  numBytes += cVar_init_f(&cVar_6CHoxBj5, 0.0f);
  numBytes += cVar_init_f(&cVar_wf9SjgHj, 0.0f);
  numBytes += cVar_init_f(&cVar_Eq64sAWg, 0.0f);
  numBytes += cVar_init_f(&cVar_tftUUAkB, 0.0f);
  numBytes += cVar_init_f(&cVar_K8uNbnw3, 0.0f);
  numBytes += cVar_init_f(&cVar_gaTtPg7v, 0.0f);
  numBytes += cVar_init_f(&cVar_JeZDbBOQ, 0.0f);
  numBytes += cVar_init_f(&cVar_Qaxd6Xxy, 0.0f);
  numBytes += cVar_init_f(&cVar_LBDlD8pW, 0.0f);
  numBytes += cVar_init_f(&cVar_AsGFWSaJ, 0.0f);
  numBytes += cVar_init_f(&cVar_lAsY5tcZ, 0.0f);
  numBytes += cVar_init_s(&cVar_KQG7ykps, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_eVTQZXAE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_969NImFN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_40RNGxya, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_jjuyIBuO, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_eA6drEmr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Lhe2NSyj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WCbPafOI, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_u0RD8hMa, 0.0f);
  numBytes += cDelay_init(this, &cDelay_trtRAj9p, 0.0f);
  numBytes += hTable_init(&hTable_CuvInPnX, 256);
  numBytes += cDelay_init(this, &cDelay_WfJ20FbN, 0.0f);
  numBytes += cDelay_init(this, &cDelay_YPGrWu0i, 0.0f);
  numBytes += hTable_init(&hTable_kG9lOzhM, 256);
  numBytes += cVar_init_f(&cVar_oQ8z2yMz, 14.0f);
  numBytes += cBinop_init(&cBinop_2bMzNsUr, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_j4hLGAjg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qKUQPuyb, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lRQOTshf, 14.0f);
  numBytes += cBinop_init(&cBinop_41oRICIE, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6ctDOYqq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fNgdwJZ9, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_gwmnlr71, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_5EQmuUeb, 1, -1);
  numBytes += cVar_init_f(&cVar_gVAvyOWL, 0.2f);
  numBytes += cSlice_init(&cSlice_Mx8reY3b, 1, -1);
  numBytes += cVar_init_f(&cVar_oweIRwK3, 0.0f);
  numBytes += cSlice_init(&cSlice_Dg1A3GY4, 1, -1);
  numBytes += cVar_init_f(&cVar_uNquXJXk, 2.0f);
  numBytes += cSlice_init(&cSlice_NmUfA5CB, 1, -1);
  numBytes += cVar_init_f(&cVar_wjvvtD3f, 0.5f);
  numBytes += cVar_init_s(&cVar_Ws5nznNG, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_Z2LrQjgu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_M9n5Kew2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9u2iFs9D, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_JdcI1YcF, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_PPkfCQZE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bv9k39QX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Spn83Wkr, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_cvErsxcc, 0.0f);
  numBytes += cDelay_init(this, &cDelay_WUAhUyFV, 0.0f);
  numBytes += hTable_init(&hTable_IhplWmh2, 256);
  numBytes += cDelay_init(this, &cDelay_PQ4E5k8b, 0.0f);
  numBytes += cDelay_init(this, &cDelay_PynSFc0J, 0.0f);
  numBytes += hTable_init(&hTable_OpaxfIr3, 256);
  numBytes += cVar_init_f(&cVar_hFIAMtKg, 14.0f);
  numBytes += cBinop_init(&cBinop_oIaNZnDT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_RGrBiikX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7Dntbjv6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_yQZAMZMb, 14.0f);
  numBytes += cBinop_init(&cBinop_jkHhwr1f, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_bM8FWsbd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bwGQBkaT, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_ViWC7wC0, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_LUOy5VIF, 1, -1);
  numBytes += cVar_init_f(&cVar_EuzTU5kA, 0.2f);
  numBytes += cSlice_init(&cSlice_vO6eD5ti, 1, -1);
  numBytes += cVar_init_f(&cVar_ah2Bzm6d, 0.0f);
  numBytes += cSlice_init(&cSlice_VtS81PuR, 1, -1);
  numBytes += cVar_init_f(&cVar_DgOouRHM, 2.0f);
  numBytes += cSlice_init(&cSlice_y1UvzKrQ, 1, -1);
  numBytes += cVar_init_f(&cVar_hpYIY4cT, 0.5f);
  numBytes += cVar_init_s(&cVar_eZRUIBDg, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_EDNKlKaW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_T8itcdB4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eHHgtdd6, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_fFGDjsI5, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_JlDaTDRE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pKK0T04r, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_H8nkLRH6, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_PBp2AAVR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_4pigOcmK, 0.0f);
  numBytes += hTable_init(&hTable_pKcaIv8I, 256);
  numBytes += cDelay_init(this, &cDelay_N6LYY0BV, 0.0f);
  numBytes += cDelay_init(this, &cDelay_mqQ3Qgl4, 0.0f);
  numBytes += hTable_init(&hTable_8uICRold, 256);
  numBytes += cVar_init_f(&cVar_vpOCKzAQ, 14.0f);
  numBytes += cBinop_init(&cBinop_zARDqWrz, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_WMAdMGpt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_boVjYMgV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_CBlHvbAM, 14.0f);
  numBytes += cBinop_init(&cBinop_yV0SODN6, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_RtNvuHLL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MWo5s6U8, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_bBzdmUOp, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_7UrY2ixh, 1, -1);
  numBytes += cVar_init_f(&cVar_zYmdlLfs, 0.2f);
  numBytes += cSlice_init(&cSlice_Mj2XP8hY, 1, -1);
  numBytes += cVar_init_f(&cVar_24jZRmJ4, 0.0f);
  numBytes += cSlice_init(&cSlice_zFJSDIqu, 1, -1);
  numBytes += cVar_init_f(&cVar_e7F8AU3M, 2.0f);
  numBytes += cSlice_init(&cSlice_8S2oy9kg, 1, -1);
  numBytes += cVar_init_f(&cVar_oPb15FdX, 0.5f);
  numBytes += sVarf_init(&sVarf_4c0gpebP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TV1FH8i4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Aycd31VY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7VwNsx3U, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7LdfaMOP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TQKl8qWC, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_CuvInPnX);
  hTable_free(&hTable_kG9lOzhM);
  hTable_free(&hTable_IhplWmh2);
  hTable_free(&hTable_OpaxfIr3);
  hTable_free(&hTable_pKcaIv8I);
  hTable_free(&hTable_8uICRold);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_CuvInPnX; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_kG9lOzhM; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_IhplWmh2; // del-1397-flanger-r
    case 0x578173CB: return &hTable_OpaxfIr3; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_pKcaIv8I; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_8uICRold; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SibGcc37_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DHfxozQr_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yBvra1eL_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f16dnZVx_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZtcXzXzo_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H7031Lll_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_u82RfmiY_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5dzVTMbl_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QseBfnp1_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8XolARBA_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bkvmLfXr_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_68jjmYb9_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p01iQsNo_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SPC7BNVv_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pv3Qk4JK_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VP2TwDxh_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bppXsM5k_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t955SPvu_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LoxtYd4o_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jLYe49qP_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Rz2itSst_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0RBq4W8s_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BAUPCgLo_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R0mdhKRR_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XSR3B5Y3_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SwN2TVsV_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uSM9uocJ_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_anO72fYv_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LEm99LJD_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9BmCqrge_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xsTCBJ1H_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_joG2zovO_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wGDEpUJZ_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZKNbgZNN_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZxdvHYs4_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hfG207lW_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CLg5Kunj_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6I5z6LSb_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SxzSNtJo_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qolzBByd_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ki3etGhv_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q4Lu4VNK_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K7WbD0ac_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LsdbZyUa_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1BhqQXMW_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kE0Pr55n_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VRrN7hjv_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bcsud2vH_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_g6kRzX6z_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_101njFmD_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ORFojeBP_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qOjseGfL_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wBna76n8_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_V8wAMUmL_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XhDCbGUR_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gXjFMqpT_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cEbUeIOB_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_Djpulr68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_maNiKOLa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_j1yJadUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wIa5mLDe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_gUsGRDS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GJ663iW5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ngGNSCZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6eSOIxEO_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_deh8PrzC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hJBswij6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RwjyEscC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_vNXwLjxJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WWX4SoSV, 0, m, &cSlice_WWX4SoSV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DkkvJjDo_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_WWX4SoSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ovpYBZuO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ovpYBZuO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_joOyklcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ovpYBZuO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ovpYBZuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LoxtYd4o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_JgKVOyRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ossfvNqx_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_SkB6mcrm, 0, m, &cIf_SkB6mcrm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_SkB6mcrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_m8q57hYL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_2gAcgqff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_exirB1yk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ZBhSio3n_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_bqwDNHro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DS4xxbSr, HV_BINOP_POW, 0, m, &cBinop_DS4xxbSr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DS4xxbSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kxmK4Olg, 0, m, &cIf_kxmK4Olg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TyW6yUoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_eZ6285m9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WQBAoStn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2gAcgqff, 0, m, &cIf_2gAcgqff_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_H3W761Ji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vbKqecN9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vbKqecN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2gAcgqff, 1, m, &cIf_2gAcgqff_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZBhSio3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TyW6yUoM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_exirB1yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_kxmK4Olg, 0, m, &cIf_kxmK4Olg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eZ6285m9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DS4xxbSr, HV_BINOP_POW, 1, m, &cBinop_DS4xxbSr_sendMessage);
  cMsg_bqwDNHro_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_kxmK4Olg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_mPmOimLC, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_ossfvNqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SkB6mcrm, 1, m, &cIf_SkB6mcrm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_m8q57hYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sJjo3nY4, HV_BINOP_GREATER_THAN, 1, m, &cBinop_sJjo3nY4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9jnJNtJ4, HV_BINOP_EQ, 1, m, &cBinop_9jnJNtJ4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UO6piCuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ujbIV6Fx, HV_BINOP_ADD, 0, m, &cBinop_ujbIV6Fx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ujbIV6Fx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3W761Ji_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WQBAoStn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sJjo3nY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kxmK4Olg, 1, m, &cIf_kxmK4Olg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9jnJNtJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9KsOVxnl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_9KsOVxnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mPmOimLC, m);
}

void Heavy_WSTD_FL3NGR::cCast_4ZYD36im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ujbIV6Fx, HV_BINOP_ADD, 1, m, &cBinop_ujbIV6Fx_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sJjo3nY4, HV_BINOP_GREATER_THAN, 0, m, &cBinop_sJjo3nY4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9jnJNtJ4, HV_BINOP_EQ, 0, m, &cBinop_9jnJNtJ4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_p4T6oVpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JgKVOyRh, 0, m, &cVar_JgKVOyRh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pxrdKnwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UO6piCuZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_sD9eOi4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eZhpVGq1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_PEJdc73R, 0, m, &cIf_PEJdc73R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_PEJdc73R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8mtvxzRk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_HfyfyaDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_QWZIBwh1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1SvM62pw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_XsO4m9U1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MP4MC7vD, HV_BINOP_POW, 0, m, &cBinop_MP4MC7vD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MP4MC7vD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dlkUdWOR, 0, m, &cIf_dlkUdWOR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tHE9NcZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_DAKc8qYk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1qpKZiK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HfyfyaDM, 0, m, &cIf_HfyfyaDM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PLhT8IRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2cpKBvnP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2cpKBvnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HfyfyaDM, 1, m, &cIf_HfyfyaDM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1SvM62pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_tHE9NcZ3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QWZIBwh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_dlkUdWOR, 0, m, &cIf_dlkUdWOR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DAKc8qYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MP4MC7vD, HV_BINOP_POW, 1, m, &cBinop_MP4MC7vD_sendMessage);
  cMsg_XsO4m9U1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_dlkUdWOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_foHhUfQf_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_abrgrRyB_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_bJkwVQYh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_eZhpVGq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PEJdc73R, 1, m, &cIf_PEJdc73R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8mtvxzRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eJ1QKofa, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eJ1QKofa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7SQBNfU2, HV_BINOP_EQ, 1, m, &cBinop_7SQBNfU2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_w7iFWsJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_L7ifAmW9, HV_BINOP_ADD, 0, m, &cBinop_L7ifAmW9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_L7ifAmW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PLhT8IRk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1qpKZiK7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eJ1QKofa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dlkUdWOR, 1, m, &cIf_dlkUdWOR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7SQBNfU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rrrzdB8G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_rrrzdB8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_foHhUfQf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_abrgrRyB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_bJkwVQYh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0SGdCGgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sD9eOi4j, 0, m, &cVar_sD9eOi4j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nRxU5HZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w7iFWsJ8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_cJGLydwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L7ifAmW9, HV_BINOP_ADD, 1, m, &cBinop_L7ifAmW9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eJ1QKofa, HV_BINOP_GREATER_THAN, 0, m, &cBinop_eJ1QKofa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7SQBNfU2, HV_BINOP_EQ, 0, m, &cBinop_7SQBNfU2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_LlXuA8Yz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5aiqLuHK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_hJKo1Ao4, 0, m, &cIf_hJKo1Ao4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_hJKo1Ao4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QdYZcwTo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_t9cNNq6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_sfYNk5LI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_RAJ8d6ac_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_ic3KTqm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_f1pSMiI1, HV_BINOP_POW, 0, m, &cBinop_f1pSMiI1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_f1pSMiI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0MpbyJx9, 0, m, &cIf_0MpbyJx9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GTcs4SWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_MYHZqOFt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TaOMTBmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t9cNNq6Q, 0, m, &cIf_t9cNNq6Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hmhFBXsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pPLILOgU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pPLILOgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t9cNNq6Q, 1, m, &cIf_t9cNNq6Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RAJ8d6ac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GTcs4SWO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sfYNk5LI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0MpbyJx9, 0, m, &cIf_0MpbyJx9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MYHZqOFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f1pSMiI1, HV_BINOP_POW, 1, m, &cBinop_f1pSMiI1_sendMessage);
  cMsg_ic3KTqm3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_0MpbyJx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_v0FRB8ij, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_5aiqLuHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hJKo1Ao4, 1, m, &cIf_hJKo1Ao4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QdYZcwTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_le4nuK2h, HV_BINOP_GREATER_THAN, 1, m, &cBinop_le4nuK2h_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zjA9MggL, HV_BINOP_EQ, 1, m, &cBinop_zjA9MggL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3zq1zGes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cv9QDcpl, HV_BINOP_ADD, 0, m, &cBinop_cv9QDcpl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cv9QDcpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hmhFBXsa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TaOMTBmZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_le4nuK2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0MpbyJx9, 1, m, &cIf_0MpbyJx9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zjA9MggL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_94iCyyMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_94iCyyMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_v0FRB8ij, m);
}

void Heavy_WSTD_FL3NGR::cCast_1zzw11fJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LlXuA8Yz, 0, m, &cVar_LlXuA8Yz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lHnwEA0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3zq1zGes_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_iiO55j3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cv9QDcpl, HV_BINOP_ADD, 1, m, &cBinop_cv9QDcpl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_le4nuK2h, HV_BINOP_GREATER_THAN, 0, m, &cBinop_le4nuK2h_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zjA9MggL, HV_BINOP_EQ, 0, m, &cBinop_zjA9MggL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_THnYrj0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_mm7TNZRA, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_l3TSRU8o_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0Nu3Rzz9, 0, m, &cSlice_0Nu3Rzz9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5U7nojAI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_0Nu3Rzz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RUuviImf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RUuviImf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_K00DKf2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RUuviImf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_RUuviImf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bppXsM5k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_5U7nojAI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EkAKc7Zy, 0, m, &cSlice_EkAKc7Zy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vNXwLjxJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_EkAKc7Zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iaguSQA4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iaguSQA4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_0pDF8R2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iaguSQA4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_iaguSQA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Rz2itSst_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_DkkvJjDo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IMJyl29p, 0, m, &cSlice_IMJyl29p_sendMessage);
      break;
    }
    default: {
      cSwitchcase_o4oPXJea_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_IMJyl29p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YE0MxjuF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YE0MxjuF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_h7xfPepr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YE0MxjuF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_YE0MxjuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t955SPvu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_o4oPXJea_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vGSCwVpv, 0, m, &cSlice_vGSCwVpv_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_vGSCwVpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_n2y1wnWR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_n2y1wnWR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_GsPFBawi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n2y1wnWR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_n2y1wnWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jLYe49qP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_rrLIdwdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZfhFo6jN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_BJcf8YRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bl4AXA1n, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_uJ4rKjxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sIDkO21r, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_vCpzLVkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qfXxonEZ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mh3jaiRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YSdc7hoN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7GUbDvnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JmTboUQb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_JmTboUQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TgByK9SX, HV_BINOP_DIVIDE, 1, m, &cBinop_TgByK9SX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZOXsp6D6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_n6JFFxBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_SFOLaMqf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sgPl8uGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_n6JFFxBt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SFOLaMqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TgByK9SX, HV_BINOP_DIVIDE, 0, m, &cBinop_TgByK9SX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZOXsp6D6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sgPl8uGR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TgByK9SX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D9QoD2vE, HV_BINOP_MULTIPLY, 1, m, &cBinop_D9QoD2vE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D9QoD2vE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VhvJOuHe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1qyWoDCE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_7x8bPfyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_o0l6Oia9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_ZEpfluCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7cZUSGcU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uDeUupNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Gj69xS9b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Gj69xS9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D9QoD2vE, HV_BINOP_MULTIPLY, 0, m, &cBinop_D9QoD2vE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_y7oaCjC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_mJQeYht5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mJQeYht5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XWES42oU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YGfT0u93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DfTnkouB, 1, m, &cVar_DfTnkouB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_DfTnkouB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NQdjwBBf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_mXJuAHcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tKsvCKDT, HV_BINOP_MULTIPLY, 1, m, &cBinop_tKsvCKDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pQvJ4yvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mXJuAHcq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rnAea0Mc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GM4MVpV0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GM4MVpV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NxvB02cU, HV_BINOP_MULTIPLY, 1, m, &cBinop_NxvB02cU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CPBR73tQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dDZGaLjR, HV_BINOP_MULTIPLY, 1, m, &cBinop_dDZGaLjR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_maFwtw3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CPBR73tQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fkrvg8FM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uoIRINco, HV_BINOP_MULTIPLY, 1, m, &cBinop_uoIRINco_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EbHQLd94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rgJbDFiw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rgJbDFiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yUTaYghs, HV_BINOP_MULTIPLY, 1, m, &cBinop_yUTaYghs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_tIs6ieDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VqP6jI4I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_uDeUupNn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nND2TO7z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_iFm0dYxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_y7oaCjC9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1qyWoDCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ZEpfluCG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VhvJOuHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_7x8bPfyt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_o0l6Oia9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R0mdhKRR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_7cZUSGcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BAUPCgLo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_B1hHipgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0RBq4W8s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_XWES42oU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0YgRthew_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0YgRthew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ctELofF, HV_BINOP_MULTIPLY, 1, m, &cBinop_3ctELofF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3ctELofF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8ViwiC1Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8ViwiC1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_B1hHipgm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_NQdjwBBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wfWwbDRv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wfWwbDRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8Nk5fJvY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oyFPZB7g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PrLAttVM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aGuXI7nn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MtDfKq5q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1cG02wVJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tKsvCKDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rrLIdwdv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NxvB02cU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BJcf8YRh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dDZGaLjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uJ4rKjxG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uoIRINco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vCpzLVkg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_yUTaYghs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mh3jaiRX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_SjwWrdnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tIs6ieDn, 0, m, &cVar_tIs6ieDn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bhAMlciS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iFm0dYxw, 1, m, &cVar_iFm0dYxw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MtDfKq5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NxvB02cU, HV_BINOP_MULTIPLY, 0, m, &cBinop_NxvB02cU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8Nk5fJvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_1cG02wVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tKsvCKDT, HV_BINOP_MULTIPLY, 0, m, &cBinop_tKsvCKDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oyFPZB7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yUTaYghs, HV_BINOP_MULTIPLY, 0, m, &cBinop_yUTaYghs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_aGuXI7nn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dDZGaLjR, HV_BINOP_MULTIPLY, 0, m, &cBinop_dDZGaLjR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PrLAttVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uoIRINco, HV_BINOP_MULTIPLY, 0, m, &cBinop_uoIRINco_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nND2TO7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DfTnkouB, 0, m, &cVar_DfTnkouB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VqP6jI4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iFm0dYxw, 0, m, &cVar_iFm0dYxw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QntTySRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_87ZJY5xQ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_5ugjvz18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aX3IcceL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_vlxptQ8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0gPOkgwn, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_RARHEeQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6AqwVpLK, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_2b670ZZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EflTUh7E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_EflTUh7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5W0WCRA4, HV_BINOP_DIVIDE, 1, m, &cBinop_5W0WCRA4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3G9ZEf7X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_KURcPQW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_5XZvkxgc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kiqZgbSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_KURcPQW2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5XZvkxgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5W0WCRA4, HV_BINOP_DIVIDE, 0, m, &cBinop_5W0WCRA4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3G9ZEf7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kiqZgbSk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5W0WCRA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KNHJOU9N, HV_BINOP_MULTIPLY, 1, m, &cBinop_KNHJOU9N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KNHJOU9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jvFJ2ZVz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H9qpV29g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_QNe3eIEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xdvIi1Hh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_pgpmv55M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zuvHZwpj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aCXBjylo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_zZfxYTqv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zZfxYTqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KNHJOU9N, HV_BINOP_MULTIPLY, 0, m, &cBinop_KNHJOU9N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7y0C5b7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dioZEUvK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dioZEUvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NugFBa6W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_iegNPGlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9hH19okp, HV_BINOP_MULTIPLY, 1, m, &cBinop_9hH19okp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fKVTlVtj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MiOFTi0e, 1, m, &cVar_MiOFTi0e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dkrG556b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QCFDDuMQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_QCFDDuMQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PuLdSyd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dXUImfjg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dXUImfjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WnYFHANk, HV_BINOP_MULTIPLY, 1, m, &cBinop_WnYFHANk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_MiOFTi0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IUS8CvrS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_04UsaYyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JYgVfWz0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_aCXBjylo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4T3OjaFO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_ifs3dGjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_7y0C5b7P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_H9qpV29g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_pgpmv55M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jvFJ2ZVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_QNe3eIEz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_xdvIi1Hh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uSM9uocJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_zuvHZwpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SwN2TVsV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_1HFJvihI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XSR3B5Y3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_NugFBa6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_G50OfyMb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G50OfyMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OhPzjnif, HV_BINOP_MULTIPLY, 1, m, &cBinop_OhPzjnif_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OhPzjnif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OIqINvT4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OIqINvT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1HFJvihI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IUS8CvrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iueQ0D4l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iueQ0D4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mlpW1Met_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mc9yrqh7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xOUZHHbn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nkgD6vVT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kxH7WFoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QntTySRi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9hH19okp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5ugjvz18_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QCFDDuMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vlxptQ8b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WnYFHANk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RARHEeQ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_nj0MaffL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_04UsaYyL, 0, m, &cVar_04UsaYyL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5GN6MTYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ifs3dGjz, 1, m, &cVar_ifs3dGjz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4T3OjaFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MiOFTi0e, 0, m, &cVar_MiOFTi0e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JYgVfWz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ifs3dGjz, 0, m, &cVar_ifs3dGjz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Mc9yrqh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QCFDDuMQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_QCFDDuMQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xOUZHHbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9hH19okp, HV_BINOP_MULTIPLY, 0, m, &cBinop_9hH19okp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nkgD6vVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kxH7WFoN, HV_BINOP_MULTIPLY, 0, m, &cBinop_kxH7WFoN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mlpW1Met_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WnYFHANk, HV_BINOP_MULTIPLY, 0, m, &cBinop_WnYFHANk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wcTEdWSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uBBiKLCN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_OpQLoqKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xB5vVno0, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1kXoLItr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pvldJ8Mm, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_dgpxk4ms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_swy87GB8, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LFUwr6Xx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xSgZs37u, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LDykRvvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KKexAnpf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_KKexAnpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UIGshiny, HV_BINOP_DIVIDE, 1, m, &cBinop_UIGshiny_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fJt5ixGS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_tkEtWhl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_yQ9ODDmo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qXih2E4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_tkEtWhl0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yQ9ODDmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UIGshiny, HV_BINOP_DIVIDE, 0, m, &cBinop_UIGshiny_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fJt5ixGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qXih2E4D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UIGshiny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hTLh9lBU, HV_BINOP_MULTIPLY, 1, m, &cBinop_hTLh9lBU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hTLh9lBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yN6VfTN9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wwstX0Rd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_pD7e5hQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JuhJotWn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_4GXn2nnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_O0P7kaPa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3M2hNMDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_eBIOgIYx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eBIOgIYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hTLh9lBU, HV_BINOP_MULTIPLY, 0, m, &cBinop_hTLh9lBU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_y1qXCyoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_qXhbEpwZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qXhbEpwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ttypma7t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_RLvOg341_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5WPkB2YK, HV_BINOP_MULTIPLY, 1, m, &cBinop_5WPkB2YK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cz9YfRIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Mh8RnwMW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Mh8RnwMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RLvOg341_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bPdyfKCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5VADuGs3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5VADuGs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WvwqG9V5, HV_BINOP_MULTIPLY, 1, m, &cBinop_WvwqG9V5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qgSiiwFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nElh3BBt, HV_BINOP_MULTIPLY, 1, m, &cBinop_nElh3BBt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7DHqVzDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_19Qx5exA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_19Qx5exA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qgSiiwFi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xvgl7wNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y27o4wBt, 1, m, &cVar_Y27o4wBt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_52g27lAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PjiVBfPj, HV_BINOP_MULTIPLY, 1, m, &cBinop_PjiVBfPj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OASrjX9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uztpBLDf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uztpBLDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SA5bblYl, HV_BINOP_MULTIPLY, 1, m, &cBinop_SA5bblYl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Y27o4wBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SnLTbiDf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_0Rm0lYDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EcKcB1pb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3M2hNMDo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jTDXv0n9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_bwFlUtum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_y1qXCyoh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yN6VfTN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_pD7e5hQV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wwstX0Rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_4GXn2nnu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_JuhJotWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9BmCqrge_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_O0P7kaPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LEm99LJD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_7pVARE4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_anO72fYv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Ttypma7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zznT7Gmu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zznT7Gmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_El9s3DCX, HV_BINOP_MULTIPLY, 1, m, &cBinop_El9s3DCX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_El9s3DCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3rR14Sk4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3rR14Sk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7pVARE4p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_SnLTbiDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2tuyWwf0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2tuyWwf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GgdWPozW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0ckz8FnO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XDYl2fYs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bm88nEEI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OBFP0GbQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ieRRx8Cm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5WPkB2YK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wcTEdWSD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WvwqG9V5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OpQLoqKF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nElh3BBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1kXoLItr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_PjiVBfPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dgpxk4ms_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SA5bblYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LFUwr6Xx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_MOz0EPLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0Rm0lYDa, 0, m, &cVar_0Rm0lYDa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4s0IujHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bwFlUtum, 1, m, &cVar_bwFlUtum_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XDYl2fYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PjiVBfPj, HV_BINOP_MULTIPLY, 0, m, &cBinop_PjiVBfPj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0ckz8FnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SA5bblYl, HV_BINOP_MULTIPLY, 0, m, &cBinop_SA5bblYl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GgdWPozW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_Bm88nEEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nElh3BBt, HV_BINOP_MULTIPLY, 0, m, &cBinop_nElh3BBt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OBFP0GbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WvwqG9V5, HV_BINOP_MULTIPLY, 0, m, &cBinop_WvwqG9V5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ieRRx8Cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5WPkB2YK, HV_BINOP_MULTIPLY, 0, m, &cBinop_5WPkB2YK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jTDXv0n9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y27o4wBt, 0, m, &cVar_Y27o4wBt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EcKcB1pb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bwFlUtum, 0, m, &cVar_bwFlUtum_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_foHhUfQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_THnYrj0w, 1, m, &cIf_THnYrj0w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_a99o8YMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mm7TNZRA, m);
}

void Heavy_WSTD_FL3NGR::cBinop_abrgrRyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a99o8YMw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bJkwVQYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_THnYrj0w, 0, m, &cIf_THnYrj0w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_sYeSkaAj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_q67ejzRe, 0, m, &cSlice_q67ejzRe_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HfDgL9XH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_q67ejzRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_p4dsVkVn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_p4dsVkVn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_yvLhRkzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_p4dsVkVn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_p4dsVkVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wGDEpUJZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_FP4Chxaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oApNmuaf_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7uivgloj, 0, m, &cIf_7uivgloj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_7uivgloj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ecA3DJcK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_U5qdWlUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_HQIgA5py_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_aIOUZfOK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_HOMW9M40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LjWb8RsY, HV_BINOP_POW, 0, m, &cBinop_LjWb8RsY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LjWb8RsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZL1KiD2G, 0, m, &cIf_ZL1KiD2G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zX7jm4Xk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_3c6WF7DY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OZ4IQm7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U5qdWlUu, 0, m, &cIf_U5qdWlUu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZjM0l4Hc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Fqlm2eG9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Fqlm2eG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U5qdWlUu, 1, m, &cIf_U5qdWlUu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aIOUZfOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_zX7jm4Xk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HQIgA5py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZL1KiD2G, 0, m, &cIf_ZL1KiD2G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3c6WF7DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LjWb8RsY, HV_BINOP_POW, 1, m, &cBinop_LjWb8RsY_sendMessage);
  cMsg_HOMW9M40_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_ZL1KiD2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_XPuAdlsS, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_oApNmuaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7uivgloj, 1, m, &cIf_7uivgloj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ecA3DJcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_abVfnxVd, HV_BINOP_GREATER_THAN, 1, m, &cBinop_abVfnxVd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2daN81Q9, HV_BINOP_EQ, 1, m, &cBinop_2daN81Q9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8NHbRH5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7s05T9Lq, HV_BINOP_ADD, 0, m, &cBinop_7s05T9Lq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7s05T9Lq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZjM0l4Hc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OZ4IQm7n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_abVfnxVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZL1KiD2G, 1, m, &cIf_ZL1KiD2G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2daN81Q9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JRQNXRiM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_JRQNXRiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XPuAdlsS, m);
}

void Heavy_WSTD_FL3NGR::cCast_OgWcow4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8NHbRH5z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_hDd7dkWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7s05T9Lq, HV_BINOP_ADD, 1, m, &cBinop_7s05T9Lq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_abVfnxVd, HV_BINOP_GREATER_THAN, 0, m, &cBinop_abVfnxVd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2daN81Q9, HV_BINOP_EQ, 0, m, &cBinop_2daN81Q9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MRe0x8y2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FP4Chxaf, 0, m, &cVar_FP4Chxaf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_ccOiNUBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oNJ3sp6t_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_KVS9f7v7, 0, m, &cIf_KVS9f7v7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_KVS9f7v7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PdTtP6tO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_CM3hBLVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_V84r0sgB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_CVCFMCjH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_aEOtu8fT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XO7a0UbI, HV_BINOP_POW, 0, m, &cBinop_XO7a0UbI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XO7a0UbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y8hvx49F, 0, m, &cIf_Y8hvx49F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GG7HWgKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_MXLmVpmt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nKVvkb63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bj5jGZrP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oPmOO1qk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CM3hBLVc, 0, m, &cIf_CM3hBLVc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bj5jGZrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CM3hBLVc, 1, m, &cIf_CM3hBLVc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CVCFMCjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GG7HWgKq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_V84r0sgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Y8hvx49F, 0, m, &cIf_Y8hvx49F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MXLmVpmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XO7a0UbI, HV_BINOP_POW, 1, m, &cBinop_XO7a0UbI_sendMessage);
  cMsg_aEOtu8fT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_Y8hvx49F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eERvkSws_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_88aFP8lf_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_71VaLqfZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_oNJ3sp6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KVS9f7v7, 1, m, &cIf_KVS9f7v7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PdTtP6tO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NBMfISfy, HV_BINOP_GREATER_THAN, 1, m, &cBinop_NBMfISfy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_14VeVwlB, HV_BINOP_EQ, 1, m, &cBinop_14VeVwlB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_50FyI8ng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gGC0kjgD, HV_BINOP_ADD, 0, m, &cBinop_gGC0kjgD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gGC0kjgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nKVvkb63_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oPmOO1qk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NBMfISfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y8hvx49F, 1, m, &cIf_Y8hvx49F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_14VeVwlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SVgqLnrL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_SVgqLnrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eERvkSws_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_88aFP8lf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_71VaLqfZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8bwkFZqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ccOiNUBO, 0, m, &cVar_ccOiNUBO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hrIF63ZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_50FyI8ng_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_QHy3RZqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gGC0kjgD, HV_BINOP_ADD, 1, m, &cBinop_gGC0kjgD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NBMfISfy, HV_BINOP_GREATER_THAN, 0, m, &cBinop_NBMfISfy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_14VeVwlB, HV_BINOP_EQ, 0, m, &cBinop_14VeVwlB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_RkZzwcsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3UUOeZqW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_XaD3P38X, 0, m, &cIf_XaD3P38X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_XaD3P38X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JltqHnV1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_tl0uE9yS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_61sQBOsO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_sG45ZJLR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_V5BylUSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zIiQfyEh, HV_BINOP_POW, 0, m, &cBinop_zIiQfyEh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zIiQfyEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_keTyoCYA, 0, m, &cIf_keTyoCYA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wauMstrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_spv69bqD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZU2Hd2pS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_w5IEV6Jm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iEolB4eA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tl0uE9yS, 0, m, &cIf_tl0uE9yS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_w5IEV6Jm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tl0uE9yS, 1, m, &cIf_tl0uE9yS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sG45ZJLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_wauMstrN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_61sQBOsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_keTyoCYA, 0, m, &cIf_keTyoCYA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_spv69bqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zIiQfyEh, HV_BINOP_POW, 1, m, &cBinop_zIiQfyEh_sendMessage);
  cMsg_V5BylUSG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_keTyoCYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_cZsUDC5d, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_3UUOeZqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XaD3P38X, 1, m, &cIf_XaD3P38X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JltqHnV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x5A7zUQN, HV_BINOP_GREATER_THAN, 1, m, &cBinop_x5A7zUQN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_S1VxxopG, HV_BINOP_EQ, 1, m, &cBinop_S1VxxopG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cjIBLTqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bTUadL91, HV_BINOP_ADD, 0, m, &cBinop_bTUadL91_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bTUadL91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZU2Hd2pS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iEolB4eA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x5A7zUQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_keTyoCYA, 1, m, &cIf_keTyoCYA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_S1VxxopG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JD16diif_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_JD16diif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cZsUDC5d, m);
}

void Heavy_WSTD_FL3NGR::cCast_0vHG2roX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RkZzwcsi, 0, m, &cVar_RkZzwcsi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5osrV0Dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cjIBLTqk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_Ka4PavS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bTUadL91, HV_BINOP_ADD, 1, m, &cBinop_bTUadL91_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_x5A7zUQN, HV_BINOP_GREATER_THAN, 0, m, &cBinop_x5A7zUQN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_S1VxxopG, HV_BINOP_EQ, 0, m, &cBinop_S1VxxopG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_OfOBL9Uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_dfvj6u83, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_lfp5j69g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hYdQ79Ad, 0, m, &cSlice_hYdQ79Ad_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2kv6loZS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_hYdQ79Ad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EEtZEHZn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EEtZEHZn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ELX8H5tX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EEtZEHZn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_EEtZEHZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xsTCBJ1H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_2kv6loZS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NIaA3xpH, 0, m, &cSlice_NIaA3xpH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sYeSkaAj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_NIaA3xpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LZm8izln_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LZm8izln_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Ff9gBaHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LZm8izln_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_LZm8izln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZxdvHYs4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_HfDgL9XH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UAZtmTE9, 0, m, &cSlice_UAZtmTE9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_16KyjMkA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_UAZtmTE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zPEza1Tk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zPEza1Tk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ecbia8Pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zPEza1Tk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_zPEza1Tk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_joG2zovO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_16KyjMkA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ELgV1INm, 0, m, &cSlice_ELgV1INm_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ELgV1INm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_I5emarPT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_I5emarPT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_afYPBMtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_I5emarPT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_I5emarPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZKNbgZNN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_U1hwH62s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hy83DlQU, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_WFwWgseP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mJ1jJWDw, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_slFFbzGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bs4PUEm6, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_55XNJV0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FxFRunxE, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7JXv3yGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BFtO5Bf4, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_4Q08hwrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_l28h6MWp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_l28h6MWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9mp2AOv, HV_BINOP_DIVIDE, 1, m, &cBinop_c9mp2AOv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XicXbmTq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_lp4oN0eC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_h4JV9llU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_j2B4Pip3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_lp4oN0eC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h4JV9llU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9mp2AOv, HV_BINOP_DIVIDE, 0, m, &cBinop_c9mp2AOv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XicXbmTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j2B4Pip3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_c9mp2AOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UflnVjxn, HV_BINOP_MULTIPLY, 1, m, &cBinop_UflnVjxn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UflnVjxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pr3xSYsS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vMJDUt63_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_CP9jOPW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pzL37rC6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_R1UOA84n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NqJXQVtS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_epUrU6eF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_pYEkw0Pj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pYEkw0Pj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UflnVjxn, HV_BINOP_MULTIPLY, 0, m, &cBinop_UflnVjxn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iXtNq6hN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_AqCC69Ru_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AqCC69Ru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iB0hEDTu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3YAqGUHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zHVl6Pnf, 1, m, &cVar_zHVl6Pnf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_zHVl6Pnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zDLXczxo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_DMMkEJle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MzHpZyZg, HV_BINOP_MULTIPLY, 1, m, &cBinop_MzHpZyZg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1oIVPDlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DMMkEJle_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rSA4bRR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_AfF99GhN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AfF99GhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xVlPtw6w, HV_BINOP_MULTIPLY, 1, m, &cBinop_xVlPtw6w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Vny0Yxyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TrdwuWL6, HV_BINOP_MULTIPLY, 1, m, &cBinop_TrdwuWL6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6QuakjNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Vny0Yxyg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tu2QD0t7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9JLJsYWn, HV_BINOP_MULTIPLY, 1, m, &cBinop_9JLJsYWn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KS4ZzwQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kttjqBN2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kttjqBN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UyQcZ5Cq, HV_BINOP_MULTIPLY, 1, m, &cBinop_UyQcZ5Cq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Frd23k9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TIH8GZzV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_epUrU6eF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y8yPMFZk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_dCkjEzyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_iXtNq6hN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vMJDUt63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_R1UOA84n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pr3xSYsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_CP9jOPW2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_pzL37rC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6I5z6LSb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_NqJXQVtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CLg5Kunj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_wkqEVW0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hfG207lW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_iB0hEDTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VVb71CLH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VVb71CLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3JdKKtUV, HV_BINOP_MULTIPLY, 1, m, &cBinop_3JdKKtUV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3JdKKtUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_19z4i7ej_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_19z4i7ej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wkqEVW0D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_zDLXczxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_g76tKVoc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g76tKVoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PYCdBNs0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CcXHXkO0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zqoMWVaa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DeoFDXXl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_95avtJ96_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CDkNrJ5m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MzHpZyZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U1hwH62s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xVlPtw6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WFwWgseP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TrdwuWL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_slFFbzGI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9JLJsYWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_55XNJV0K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UyQcZ5Cq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7JXv3yGc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_rqsdGO0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Frd23k9e, 0, m, &cVar_Frd23k9e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jIRQX3Am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dCkjEzyZ, 1, m, &cVar_dCkjEzyZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_95avtJ96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xVlPtw6w, HV_BINOP_MULTIPLY, 0, m, &cBinop_xVlPtw6w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zqoMWVaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9JLJsYWn, HV_BINOP_MULTIPLY, 0, m, &cBinop_9JLJsYWn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CcXHXkO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UyQcZ5Cq, HV_BINOP_MULTIPLY, 0, m, &cBinop_UyQcZ5Cq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PYCdBNs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_DeoFDXXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TrdwuWL6, HV_BINOP_MULTIPLY, 0, m, &cBinop_TrdwuWL6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CDkNrJ5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MzHpZyZg, HV_BINOP_MULTIPLY, 0, m, &cBinop_MzHpZyZg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TIH8GZzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dCkjEzyZ, 0, m, &cVar_dCkjEzyZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_y8yPMFZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zHVl6Pnf, 0, m, &cVar_zHVl6Pnf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_H6sq1hjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hcqo1PaB, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_2eiB5ils_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0CPRdipH, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_vkyb6gqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i06P3QRt, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_bvn6OxOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nFlyuYqM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ngucPYkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FvsJzo99_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_FvsJzo99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v5G1ZD4k, HV_BINOP_DIVIDE, 1, m, &cBinop_v5G1ZD4k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D0QSKZIr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_0M1KwDAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_m6jozOIi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wmmbAHgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_0M1KwDAF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_m6jozOIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v5G1ZD4k, HV_BINOP_DIVIDE, 0, m, &cBinop_v5G1ZD4k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_D0QSKZIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wmmbAHgG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_v5G1ZD4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jUxf1zN2, HV_BINOP_MULTIPLY, 1, m, &cBinop_jUxf1zN2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jUxf1zN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TrY2z8y5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iTBvmw3F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_vkU5R2R2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XJoR5SgT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_R9xepBmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_It2VlqLm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XjLQlTE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_XJzHURce_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XJzHURce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jUxf1zN2, HV_BINOP_MULTIPLY, 0, m, &cBinop_jUxf1zN2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_230GCr71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_nM8aXxfK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nM8aXxfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fhrerZ32_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CJA6tJx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j0d2xPfr, HV_BINOP_MULTIPLY, 1, m, &cBinop_j0d2xPfr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TRT8wIYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gZidi2tQ, 1, m, &cVar_gZidi2tQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xqjxLinn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nmx3RZtg, HV_BINOP_MULTIPLY, 1, m, &cBinop_Nmx3RZtg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4XN5SYFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_g8kFi1R1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g8kFi1R1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B4lPJrv9, HV_BINOP_MULTIPLY, 1, m, &cBinop_B4lPJrv9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_gZidi2tQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mLjrpWZJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ERvjzQls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hnqFsMer_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XjLQlTE2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bIc6s46M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_oPHDDV6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_230GCr71_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iTBvmw3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_R9xepBmV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TrY2z8y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_vkU5R2R2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_XJoR5SgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ki3etGhv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_It2VlqLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qolzBByd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_4FMObfMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SxzSNtJo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fhrerZ32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lSdOmlYZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lSdOmlYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jEc5WTkm, HV_BINOP_MULTIPLY, 1, m, &cBinop_jEc5WTkm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jEc5WTkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pgYOsz3p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pgYOsz3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4FMObfMt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_mLjrpWZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ze2XaBuo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ze2XaBuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OT1saa2Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FgXk5Dx2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7G5BxjME_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Duwq7FpW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4mS1orc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H6sq1hjg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_j0d2xPfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2eiB5ils_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Nmx3RZtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vkyb6gqs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_B4lPJrv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bvn6OxOn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_OsnYKINb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ERvjzQls, 0, m, &cVar_ERvjzQls_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SxLFRTQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oPHDDV6K, 1, m, &cVar_oPHDDV6K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bIc6s46M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gZidi2tQ, 0, m, &cVar_gZidi2tQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hnqFsMer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oPHDDV6K, 0, m, &cVar_oPHDDV6K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FgXk5Dx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nmx3RZtg, HV_BINOP_MULTIPLY, 0, m, &cBinop_Nmx3RZtg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OT1saa2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B4lPJrv9, HV_BINOP_MULTIPLY, 0, m, &cBinop_B4lPJrv9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Duwq7FpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4mS1orc1, HV_BINOP_MULTIPLY, 0, m, &cBinop_4mS1orc1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7G5BxjME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j0d2xPfr, HV_BINOP_MULTIPLY, 0, m, &cBinop_j0d2xPfr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Lyp8Ko0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qqkpIn1F, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hqy3g9CV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UDG2TRd8, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_kwfH1Jk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WPQY1JXp, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_oySbuyis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZVN07b2L, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_cHUD4usy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wPcwuVhg, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ygmaZFYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3rFf9WWJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_3rFf9WWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s3ta5kis, HV_BINOP_DIVIDE, 1, m, &cBinop_s3ta5kis_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vh893mbS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_7dxeIZsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_CQ9RXcVI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_iqMkg6LI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_7dxeIZsC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CQ9RXcVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s3ta5kis, HV_BINOP_DIVIDE, 0, m, &cBinop_s3ta5kis_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vh893mbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iqMkg6LI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_s3ta5kis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_28GNFqzM, HV_BINOP_MULTIPLY, 1, m, &cBinop_28GNFqzM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_28GNFqzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X5v7esAr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zibKD7Ag_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_N6OYaAvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZJCHONNv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_16HBHWkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_shX60otR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UiqgnFQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_8FyzW3T0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8FyzW3T0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_28GNFqzM, HV_BINOP_MULTIPLY, 0, m, &cBinop_28GNFqzM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HsGueu5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_uOJCRsvp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uOJCRsvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JOY6RTCg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9c0mIX9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iVuftvxL, HV_BINOP_MULTIPLY, 1, m, &cBinop_iVuftvxL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CDE1RavZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3ZQPXWVk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3ZQPXWVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9c0mIX9E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_illfGxsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ddw19NFR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ddw19NFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YjJgPbKD, HV_BINOP_MULTIPLY, 1, m, &cBinop_YjJgPbKD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pQpJEpoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W3B5fzQc, HV_BINOP_MULTIPLY, 1, m, &cBinop_W3B5fzQc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cVck3Ilb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_u4Tdb9ZZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_u4Tdb9ZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pQpJEpoc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4ClJXDQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6QqpBWZy, 1, m, &cVar_6QqpBWZy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Xx48ScxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_byqLvUw5, HV_BINOP_MULTIPLY, 1, m, &cBinop_byqLvUw5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GxoH9XPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yw3mmXN4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yw3mmXN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZIAQdjL5, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZIAQdjL5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_6QqpBWZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4s2OhaFV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_kxATIwzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EQ1N4TCF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_UiqgnFQs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hdz6kH0x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_G1Yu4qJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_HsGueu5N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zibKD7Ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_16HBHWkM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_X5v7esAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_N6OYaAvJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_ZJCHONNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LsdbZyUa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_shX60otR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_K7WbD0ac_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_76bKwY1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Q4Lu4VNK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_JOY6RTCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uJiohgOP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uJiohgOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOA1MqsV, HV_BINOP_MULTIPLY, 1, m, &cBinop_bOA1MqsV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bOA1MqsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_c1HJPv3M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c1HJPv3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_76bKwY1H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_4s2OhaFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pCYH3V16_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pCYH3V16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OtSkh2m6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FkXoeQAT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ArGx6SNp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pNjx4X7G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OJLItscq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9pkeNuvF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iVuftvxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lyp8Ko0b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YjJgPbKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hqy3g9CV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_W3B5fzQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kwfH1Jk9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_byqLvUw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oySbuyis_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZIAQdjL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cHUD4usy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_ntOJTryb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kxATIwzy, 0, m, &cVar_kxATIwzy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fmC6LYrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G1Yu4qJM, 1, m, &cVar_G1Yu4qJM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OJLItscq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YjJgPbKD, HV_BINOP_MULTIPLY, 0, m, &cBinop_YjJgPbKD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pNjx4X7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W3B5fzQc, HV_BINOP_MULTIPLY, 0, m, &cBinop_W3B5fzQc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OtSkh2m6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_ArGx6SNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_byqLvUw5, HV_BINOP_MULTIPLY, 0, m, &cBinop_byqLvUw5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9pkeNuvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iVuftvxL, HV_BINOP_MULTIPLY, 0, m, &cBinop_iVuftvxL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FkXoeQAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZIAQdjL5, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZIAQdjL5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EQ1N4TCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G1Yu4qJM, 0, m, &cVar_G1Yu4qJM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hdz6kH0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6QqpBWZy, 0, m, &cVar_6QqpBWZy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eERvkSws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OfOBL9Uz, 1, m, &cIf_OfOBL9Uz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4dYRLYXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dfvj6u83, m);
}

void Heavy_WSTD_FL3NGR::cBinop_88aFP8lf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4dYRLYXd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_71VaLqfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OfOBL9Uz, 0, m, &cIf_OfOBL9Uz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_GFeVoxbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BByxVeGK, HV_BINOP_DIVIDE, 0, m, &cBinop_BByxVeGK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_RvVSyB5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EXC2qBvP, HV_BINOP_DIVIDE, 1, m, &cBinop_EXC2qBvP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BByxVeGK, HV_BINOP_DIVIDE, 1, m, &cBinop_BByxVeGK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_aZMcwYqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZFOspIvm, HV_BINOP_DIVIDE, 0, m, &cBinop_ZFOspIvm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_yKluFLqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZFOspIvm, HV_BINOP_DIVIDE, 1, m, &cBinop_ZFOspIvm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_deh8PrzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RvVSyB5V, 0, m, &cVar_RvVSyB5V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hJBswij6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GFeVoxbF, 0, m, &cVar_GFeVoxbF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_RwjyEscC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EXC2qBvP, HV_BINOP_DIVIDE, 0, m, &cBinop_EXC2qBvP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EXC2qBvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_aZMcwYqD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BByxVeGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_yKluFLqu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZFOspIvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_FUqtc1FZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_q6GeqzeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_ErSMtoMm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Fe7T6PGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_f8iMrcOR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FUqtc1FZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Fe7T6PGb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_f8iMrcOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_q6GeqzeU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ErSMtoMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RPxAbuPP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_IyzXYRds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L9YkVKeR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_6CHoxBj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9avZLr5A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_wf9SjgHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sELPSQaA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Eq64sAWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tv4wy32Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_tftUUAkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_raqrK5Lt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_K8uNbnw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rQrKZpS6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_gaTtPg7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pLbxDFts_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_JeZDbBOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2otKaHsp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Qaxd6Xxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LZh9QCt6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_LBDlD8pW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P15wxQxU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_AsGFWSaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sofZaGld_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_lAsY5tcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jWGa1sDs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Sm3FlKVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_faygGAzI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_faygGAzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_YIKPUnKJ, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_nc0jHXc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ewsofGJ0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ewsofGJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GKHbr7qG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_KQG7ykps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BibGXCUI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_cfnl2ObI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iPfOvCyV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eVTQZXAE, m);
}

void Heavy_WSTD_FL3NGR::cBinop_GKHbr7qG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_969NImFN, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BibGXCUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cfnl2ObI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iPfOvCyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_40RNGxya, m);
}

void Heavy_WSTD_FL3NGR::cMsg_bl89GruV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_05F4Nq0t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_05F4Nq0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cldusu1G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_jjuyIBuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c392M6KE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_DS61utup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_cmCCFo7I_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eA6drEmr, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cldusu1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Lhe2NSyj, m);
}

void Heavy_WSTD_FL3NGR::cMsg_c392M6KE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DS61utup_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cmCCFo7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WCbPafOI, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jZupi7Kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OVywrNjw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OVywrNjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_LRNOAnEb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_8bNQ31zL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_otqKOrIh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_ylEtEdY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_No0pAVPN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LRNOAnEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bVULe3VW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bVULe3VW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ikBToeY6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z0vInOMz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Z0vInOMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bXY1NYSQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_ikBToeY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_urAitUMu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_urAitUMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vo2nfHfR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bXY1NYSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9cCNV3Lo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9cCNV3Lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oJ00jTfy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vo2nfHfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_8bNQ31zL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oJ00jTfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_ylEtEdY1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_USy6vQNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KC9HP9GA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KC9HP9GA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8yiYrHZn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Fs3SdUbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UcUtMT2A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_UcUtMT2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_pbrIaGQS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_u0RD8hMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_u0RD8hMa, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_trtRAj9p, 0, m, &cDelay_trtRAj9p_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u0RD8hMa, 0, m, &cDelay_u0RD8hMa_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_X9hzn2TO, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_trtRAj9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_trtRAj9p, m);
  cMsg_iogSJsAS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_WCmfPkyR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_569j0Lr0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_SCD1J74O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C8NXFG9j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_CuvInPnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wzSbkIYb_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u0RD8hMa, 2, m, &cDelay_u0RD8hMa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wqLXkRzg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_C8NXFG9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_CuvInPnX, 0, m, &hTable_CuvInPnX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pbrIaGQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_SCD1J74O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_iogSJsAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_CuvInPnX, 0, m, &hTable_CuvInPnX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wqLXkRzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_u0RD8hMa, 0, m, &cDelay_u0RD8hMa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wzSbkIYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_trtRAj9p, 2, m, &cDelay_trtRAj9p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_569j0Lr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_X9hzn2TO, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_JDW0Viwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0QNNuji2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_0QNNuji2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_fPs0Ypuf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_WfJ20FbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WfJ20FbN, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YPGrWu0i, 0, m, &cDelay_YPGrWu0i_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WfJ20FbN, 0, m, &cDelay_WfJ20FbN_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YoQHommw, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_YPGrWu0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YPGrWu0i, m);
  cMsg_rbNzjWf9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_qZx4pU5T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_tZvyjCht_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_8hjnDfQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sMYtmlEZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_kG9lOzhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gKtyYKFt_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WfJ20FbN, 2, m, &cDelay_WfJ20FbN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o3QOngJy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sMYtmlEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_kG9lOzhM, 0, m, &hTable_kG9lOzhM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fPs0Ypuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_8hjnDfQm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rbNzjWf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_kG9lOzhM, 0, m, &hTable_kG9lOzhM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_o3QOngJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WfJ20FbN, 0, m, &cDelay_WfJ20FbN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_gKtyYKFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_YPGrWu0i, 2, m, &cDelay_YPGrWu0i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tZvyjCht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YoQHommw, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_oQ8z2yMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2bMzNsUr, HV_BINOP_MULTIPLY, 0, m, &cBinop_2bMzNsUr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YKOi6Gqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ThC99ISx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ThC99ISx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Reuz1mIv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2bMzNsUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_U6lOptJY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cICdhUWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2bMzNsUr, HV_BINOP_MULTIPLY, 1, m, &cBinop_2bMzNsUr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Reuz1mIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cICdhUWN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_U6lOptJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rBdaZu4b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rBdaZu4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vC2WDC9j_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qKUQPuyb, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vC2WDC9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_j4hLGAjg, m);
}

void Heavy_WSTD_FL3NGR::cVar_lRQOTshf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_41oRICIE, HV_BINOP_MULTIPLY, 0, m, &cBinop_41oRICIE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DQXy94WU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zcoMKc2c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_zcoMKc2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_khuhtQfE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_41oRICIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_973gXuTz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5q2XIdeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_41oRICIE, HV_BINOP_MULTIPLY, 1, m, &cBinop_41oRICIE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_khuhtQfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5q2XIdeH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_973gXuTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_X0byclCz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_X0byclCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_W36oQOn4_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fNgdwJZ9, m);
}

void Heavy_WSTD_FL3NGR::cBinop_W36oQOn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6ctDOYqq, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8yiYrHZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6D6WFjID, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_EM7gOMlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_AarKwEoQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TU9qNwpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_X8esIcRZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PykGMLQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_EM7gOMlu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_C3HR3EYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_gvQTUAXS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gvQTUAXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gwmnlr71, HV_BINOP_MULTIPLY, 1, m, &cBinop_gwmnlr71_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_X8esIcRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_C3HR3EYg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gwmnlr71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I1k3bV8b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_AarKwEoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gwmnlr71, HV_BINOP_MULTIPLY, 0, m, &cBinop_gwmnlr71_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_I1k3bV8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NWpG7kvh, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ALof5ntm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_g5KZI9v5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g5KZI9v5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TU9qNwpq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PykGMLQX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_SVHoocde_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5EQmuUeb, 0, m, &cSlice_5EQmuUeb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QIiiyOpO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_5EQmuUeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jx2oscpW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jx2oscpW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_gVAvyOWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jx2oscpW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_jx2oscpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kE0Pr55n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_QIiiyOpO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Mx8reY3b, 0, m, &cSlice_Mx8reY3b_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Q4sU5ssx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Mx8reY3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aSptAFzf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aSptAFzf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_oweIRwK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aSptAFzf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_aSptAFzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1BhqQXMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Q4sU5ssx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Dg1A3GY4, 0, m, &cSlice_Dg1A3GY4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3Yyf3MXQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Dg1A3GY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ugjaSy31_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ugjaSy31_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_uNquXJXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ugjaSy31_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ugjaSy31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bcsud2vH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_3Yyf3MXQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NmUfA5CB, 0, m, &cSlice_NmUfA5CB_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_NmUfA5CB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Y1lnP8te_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Y1lnP8te_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_wjvvtD3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Y1lnP8te_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Y1lnP8te_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VRrN7hjv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_otqKOrIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uucwG5Vg, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_No0pAVPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pPkQBfE5, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_L56yK466_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2zJOM1Wv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2zJOM1Wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_eEr52Rvg, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_VpMJEaFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C4NEwwM9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_C4NEwwM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qgzlqOgM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Ws5nznNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VXJNZ0xI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_q1G9EVu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_HhDUGPF9_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Z2LrQjgu, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qgzlqOgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_M9n5Kew2, m);
}

void Heavy_WSTD_FL3NGR::cMsg_VXJNZ0xI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_q1G9EVu5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HhDUGPF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9u2iFs9D, m);
}

void Heavy_WSTD_FL3NGR::cMsg_mlPSNWwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cuv2cGIU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_cuv2cGIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ajBHtU4Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_JdcI1YcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a5CFAOvV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_h15WCvn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bL14XwD4_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_PPkfCQZE, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ajBHtU4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bv9k39QX, m);
}

void Heavy_WSTD_FL3NGR::cMsg_a5CFAOvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_h15WCvn2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bL14XwD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Spn83Wkr, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lpadRUry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Lz350umu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Lz350umu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_gwfxPrpz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_XuH3LeU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_otJ21Mfu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_O6bjU1vU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qHo7ekCu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gwfxPrpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_L4aouVoY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_L4aouVoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OFbquM9g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ArcYmgiQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OFbquM9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XyjPjllT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ArcYmgiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m8Exns1L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XyjPjllT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JJydNmoO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_m8Exns1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tyuvaLkB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tyuvaLkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Kg8yFYfA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JJydNmoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_XuH3LeU1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Kg8yFYfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_O6bjU1vU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6VbXPNbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_60G4ZEri_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_60G4ZEri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UthjYmUM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_tZYTKT8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PSfazxdw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_PSfazxdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xdY0su0I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_cvErsxcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cvErsxcc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WUAhUyFV, 0, m, &cDelay_WUAhUyFV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cvErsxcc, 0, m, &cDelay_cvErsxcc_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ztn4yq5p, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_WUAhUyFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WUAhUyFV, m);
  cMsg_QlyQvAxG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_eFWKaetS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_iErJnTzL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_MKkyjK6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AZHloCJD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_IhplWmh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qsdpkYvH_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cvErsxcc, 2, m, &cDelay_cvErsxcc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7nMOjzgB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_AZHloCJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_IhplWmh2, 0, m, &hTable_IhplWmh2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xdY0su0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_MKkyjK6i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QlyQvAxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_IhplWmh2, 0, m, &hTable_IhplWmh2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7nMOjzgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cvErsxcc, 0, m, &cDelay_cvErsxcc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qsdpkYvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_WUAhUyFV, 2, m, &cDelay_WUAhUyFV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_iErJnTzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ztn4yq5p, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mKVEfAYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_t2XdD6sb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_t2XdD6sb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lTBq8nw6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_PQ4E5k8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PQ4E5k8b, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PynSFc0J, 0, m, &cDelay_PynSFc0J_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PQ4E5k8b, 0, m, &cDelay_PQ4E5k8b_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_usH4eFT3, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_PynSFc0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PynSFc0J, m);
  cMsg_kJPIluS0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_QClEjDTl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_XE9qEo9R_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_lNDmLaun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0fAjaI7K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_OpaxfIr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rEHTKlUi_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PQ4E5k8b, 2, m, &cDelay_PQ4E5k8b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ULRzKvA9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0fAjaI7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_OpaxfIr3, 0, m, &hTable_OpaxfIr3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lTBq8nw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_lNDmLaun_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kJPIluS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_OpaxfIr3, 0, m, &hTable_OpaxfIr3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ULRzKvA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PQ4E5k8b, 0, m, &cDelay_PQ4E5k8b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rEHTKlUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_PynSFc0J, 2, m, &cDelay_PynSFc0J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XE9qEo9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_usH4eFT3, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_hFIAMtKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oIaNZnDT, HV_BINOP_MULTIPLY, 0, m, &cBinop_oIaNZnDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MJznzCD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kTaLAyn4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_kTaLAyn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0sr49016_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oIaNZnDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4EHiy92y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_deckrCCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oIaNZnDT, HV_BINOP_MULTIPLY, 1, m, &cBinop_oIaNZnDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0sr49016_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_deckrCCu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4EHiy92y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_9qy5DqQG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9qy5DqQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jPOQZhSH_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7Dntbjv6, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jPOQZhSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RGrBiikX, m);
}

void Heavy_WSTD_FL3NGR::cVar_yQZAMZMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jkHhwr1f, HV_BINOP_MULTIPLY, 0, m, &cBinop_jkHhwr1f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_TUadr8r2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WotE4ecJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_WotE4ecJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5b6efDkJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jkHhwr1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SOjmYzYw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kDMkaesh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jkHhwr1f, HV_BINOP_MULTIPLY, 1, m, &cBinop_jkHhwr1f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5b6efDkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kDMkaesh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SOjmYzYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4NkxsxI9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4NkxsxI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jwePnRuY_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bwGQBkaT, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jwePnRuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bM8FWsbd, m);
}

void Heavy_WSTD_FL3NGR::cMsg_UthjYmUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fZowTnW1, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_NCLPrjWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_KiWQqJ1D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZyCzCm4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_NCLPrjWg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_w63D2sHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GFK9rMOE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RQAVSdMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1OPTwzqu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1OPTwzqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ViWC7wC0, HV_BINOP_MULTIPLY, 1, m, &cBinop_ViWC7wC0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GFK9rMOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_RQAVSdMw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ViWC7wC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GBc2Hx0U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KiWQqJ1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ViWC7wC0, HV_BINOP_MULTIPLY, 0, m, &cBinop_ViWC7wC0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GBc2Hx0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UZZ1XZZw, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_sogvUf8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_c2tlgoGJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c2tlgoGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w63D2sHQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZyCzCm4n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Eu2DrYMe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LUOy5VIF, 0, m, &cSlice_LUOy5VIF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PxhJYJCJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_LUOy5VIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EGOwm4xq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EGOwm4xq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_EuzTU5kA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EGOwm4xq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_EGOwm4xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_101njFmD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_PxhJYJCJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vO6eD5ti, 0, m, &cSlice_vO6eD5ti_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nTrJzUQp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_vO6eD5ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XVOFtoU9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XVOFtoU9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ah2Bzm6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XVOFtoU9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_XVOFtoU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_g6kRzX6z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_nTrJzUQp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VtS81PuR, 0, m, &cSlice_VtS81PuR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_SdhQA9Aa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_VtS81PuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nXECEdrx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nXECEdrx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_DgOouRHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nXECEdrx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_nXECEdrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qOjseGfL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_SdhQA9Aa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_y1UvzKrQ, 0, m, &cSlice_y1UvzKrQ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_y1UvzKrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_a4YPrioa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_a4YPrioa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_hpYIY4cT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_a4YPrioa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_a4YPrioa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ORFojeBP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_otJ21Mfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xubY7vwP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_qHo7ekCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D6Ko2NkM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_a2zC8L0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hKiSyWds_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hKiSyWds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_YeZ3J0ZZ, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Q3x5GFMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tlPj1zGq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_tlPj1zGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FG6bhinm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_eZRUIBDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NrDnZDZM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_JEsn55kI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_f2pAIPvV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EDNKlKaW, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FG6bhinm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_T8itcdB4, m);
}

void Heavy_WSTD_FL3NGR::cMsg_NrDnZDZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JEsn55kI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_f2pAIPvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_eHHgtdd6, m);
}

void Heavy_WSTD_FL3NGR::cMsg_S8Lbevro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fcwYnLbu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_fcwYnLbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6BjnFB1A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_fFGDjsI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lli4TtnP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_ZIOAqr1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9SlPMawR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_JlDaTDRE, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6BjnFB1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pKK0T04r, m);
}

void Heavy_WSTD_FL3NGR::cMsg_lli4TtnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZIOAqr1c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9SlPMawR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_H8nkLRH6, m);
}

void Heavy_WSTD_FL3NGR::cBinop_AZJQvNHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_9wL4LSUr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9wL4LSUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_yTSpde4k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_XMf4Ualp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hH3RsRlW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_izUwAHn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fHpZLh4s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_yTSpde4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tOlkgZ0R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tOlkgZ0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7G1SlTKo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vuWQ0QCC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vuWQ0QCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bVqOlDaU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_7G1SlTKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nb7He2xr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nb7He2xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5oINrFgs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bVqOlDaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tuSvWLJA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tuSvWLJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0DHiN4Xo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5oINrFgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_XMf4Ualp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0DHiN4Xo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_izUwAHn0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sXw4zGXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Ak2hLMjU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ak2hLMjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KtDbT2BM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_GyOIumc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_w0V7qY2f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_w0V7qY2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zZd7blbY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_PBp2AAVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PBp2AAVR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4pigOcmK, 0, m, &cDelay_4pigOcmK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PBp2AAVR, 0, m, &cDelay_PBp2AAVR_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cq9FxIhG, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_4pigOcmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4pigOcmK, m);
  cMsg_9AaRKVOw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Ae0PhJ2n_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_0nEbkyOL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_9AtrKYUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R2PE7Itu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_pKcaIv8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cpfidys3_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PBp2AAVR, 2, m, &cDelay_PBp2AAVR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hg0ip6sz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_R2PE7Itu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_pKcaIv8I, 0, m, &hTable_pKcaIv8I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zZd7blbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_9AtrKYUR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9AaRKVOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_pKcaIv8I, 0, m, &hTable_pKcaIv8I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Hg0ip6sz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PBp2AAVR, 0, m, &cDelay_PBp2AAVR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Cpfidys3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_4pigOcmK, 2, m, &cDelay_4pigOcmK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0nEbkyOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cq9FxIhG, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_06UqpaYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_txSS1UOs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_txSS1UOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FkKMBHy2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_N6LYY0BV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N6LYY0BV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mqQ3Qgl4, 0, m, &cDelay_mqQ3Qgl4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N6LYY0BV, 0, m, &cDelay_N6LYY0BV_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_r6u4jebs, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_mqQ3Qgl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mqQ3Qgl4, m);
  cMsg_DrjdhiwO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_wCH2nVDw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Da0FFYL3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_CvgFncoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lnLBV6G6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_8uICRold_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sOFOK2df_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N6LYY0BV, 2, m, &cDelay_N6LYY0BV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fTnkeGb5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_lnLBV6G6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_8uICRold, 0, m, &hTable_8uICRold_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FkKMBHy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_CvgFncoS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DrjdhiwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_8uICRold, 0, m, &hTable_8uICRold_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fTnkeGb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N6LYY0BV, 0, m, &cDelay_N6LYY0BV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sOFOK2df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_mqQ3Qgl4, 2, m, &cDelay_mqQ3Qgl4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Da0FFYL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_r6u4jebs, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_vpOCKzAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zARDqWrz, HV_BINOP_MULTIPLY, 0, m, &cBinop_zARDqWrz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Fh59a9Ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LxIMbHaE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_LxIMbHaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P2vaF9MM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zARDqWrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0H4JZPLx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TmqkU1tC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zARDqWrz, HV_BINOP_MULTIPLY, 1, m, &cBinop_zARDqWrz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_P2vaF9MM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TmqkU1tC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0H4JZPLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5jEsJGgV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5jEsJGgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xfX9YHRp_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_boVjYMgV, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xfX9YHRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WMAdMGpt, m);
}

void Heavy_WSTD_FL3NGR::cVar_CBlHvbAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yV0SODN6, HV_BINOP_MULTIPLY, 0, m, &cBinop_yV0SODN6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WkLa8b3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TNmOq2VM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_TNmOq2VM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bNAjSbvC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_yV0SODN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rVzXB8WW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0Io7UZCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yV0SODN6, HV_BINOP_MULTIPLY, 1, m, &cBinop_yV0SODN6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bNAjSbvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0Io7UZCh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rVzXB8WW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_eRIJ6s6b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eRIJ6s6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xjiWxI9h_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MWo5s6U8, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xjiWxI9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RtNvuHLL, m);
}

void Heavy_WSTD_FL3NGR::cMsg_KtDbT2BM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d8JPLfdU, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_uHhebgRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_wJlaF1Ha_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_izTDyEq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_uHhebgRl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jquWMkqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QCwa1fCG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vBMI8M14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5LuvUODt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5LuvUODt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bBzdmUOp, HV_BINOP_MULTIPLY, 1, m, &cBinop_bBzdmUOp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QCwa1fCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_vBMI8M14_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bBzdmUOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3VONJj29_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wJlaF1Ha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bBzdmUOp, HV_BINOP_MULTIPLY, 0, m, &cBinop_bBzdmUOp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3VONJj29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2MPwhd00, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_PKe3Y1vo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_lnVCBrLP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lnVCBrLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jquWMkqE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_izTDyEq0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_slmzORaj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7UrY2ixh, 0, m, &cSlice_7UrY2ixh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LdFZGHwa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_7UrY2ixh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SZSJ4NUE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SZSJ4NUE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_zYmdlLfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SZSJ4NUE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_SZSJ4NUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_V8wAMUmL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_LdFZGHwa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Mj2XP8hY, 0, m, &cSlice_Mj2XP8hY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_W6c7UWil_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Mj2XP8hY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VMq0XMV5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VMq0XMV5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_24jZRmJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VMq0XMV5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_VMq0XMV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wBna76n8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_W6c7UWil_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zFJSDIqu, 0, m, &cSlice_zFJSDIqu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_aBNvhKP0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_zFJSDIqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0PoTYFjO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0PoTYFjO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_e7F8AU3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0PoTYFjO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_0PoTYFjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gXjFMqpT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_aBNvhKP0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8S2oy9kg, 0, m, &cSlice_8S2oy9kg_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_8S2oy9kg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_G3jGTDGm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_G3jGTDGm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_oPb15FdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_G3jGTDGm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_G3jGTDGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XhDCbGUR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_hH3RsRlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BUvjM2kG, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_fHpZLh4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AbGIgxUB, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_maNiKOLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_l3TSRU8o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lfp5j69g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_wIa5mLDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_l3TSRU8o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lfp5j69g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GJ663iW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_l3TSRU8o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lfp5j69g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6eSOIxEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_l3TSRU8o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lfp5j69g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_RPxAbuPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_l3TSRU8o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lfp5j69g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_JkAlhsAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ngGNSCZL, 0, m, &cVar_ngGNSCZL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KuZAsp95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Djpulr68, 0, m, &cVar_Djpulr68_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j1yJadUD, 0, m, &cVar_j1yJadUD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gUsGRDS7, 0, m, &cVar_gUsGRDS7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tv4wy32Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SVHoocde_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_L9YkVKeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SVHoocde_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_9avZLr5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SVHoocde_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_sELPSQaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SVHoocde_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_yzZszgfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Eq64sAWg, 0, m, &cVar_Eq64sAWg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_chjiaWZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IyzXYRds, 0, m, &cVar_IyzXYRds_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SQaM1o59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wf9SjgHj, 0, m, &cVar_wf9SjgHj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2otKaHsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Eu2DrYMe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_raqrK5Lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Eu2DrYMe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_rQrKZpS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Eu2DrYMe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_pLbxDFts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Eu2DrYMe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_NzFwh6C3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JeZDbBOQ, 0, m, &cVar_JeZDbBOQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fe3qac3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tftUUAkB, 0, m, &cVar_tftUUAkB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TUcVD3uv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gaTtPg7v, 0, m, &cVar_gaTtPg7v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jWGa1sDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_slmzORaj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LZh9QCt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_slmzORaj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_P15wxQxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_slmzORaj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_sofZaGld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_slmzORaj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_vJFaOaEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lAsY5tcZ, 0, m, &cVar_lAsY5tcZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lknMjn4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Qaxd6Xxy, 0, m, &cVar_Qaxd6Xxy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SfsCBcaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AsGFWSaJ, 0, m, &cVar_AsGFWSaJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SibGcc37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Djpulr68, 0, m, &cVar_Djpulr68_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bkvmLfXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j1yJadUD, 0, m, &cVar_j1yJadUD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_H7031Lll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gUsGRDS7, 0, m, &cVar_gUsGRDS7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LoxtYd4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_04UsaYyL, 0, m, &cVar_04UsaYyL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_jLYe49qP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5GN6MTYv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nj0MaffL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bppXsM5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p4T6oVpa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4ZYD36im_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pxrdKnwz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_t955SPvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1zzw11fJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iiO55j3b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHnwEA0T_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Rz2itSst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0SGdCGgU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cJGLydwU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nRxU5HZH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_cEbUeIOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7GUbDvnH_sendMessage(_c, 0, m);
  cMsg_2b670ZZN_sendMessage(_c, 0, m);
  cMsg_LDykRvvD_sendMessage(_c, 0, m);
  cMsg_4Q08hwrg_sendMessage(_c, 0, m);
  cMsg_ngucPYkp_sendMessage(_c, 0, m);
  cMsg_ygmaZFYr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tIs6ieDn, 0, m, &cVar_tIs6ieDn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_04UsaYyL, 0, m, &cVar_04UsaYyL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0Rm0lYDa, 0, m, &cVar_0Rm0lYDa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Frd23k9e, 0, m, &cVar_Frd23k9e_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ERvjzQls, 0, m, &cVar_ERvjzQls_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kxATIwzy, 0, m, &cVar_kxATIwzy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_joOyklcF, 0, m, &cVar_joOyklcF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JgKVOyRh, 0, m, &cVar_JgKVOyRh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sD9eOi4j, 0, m, &cVar_sD9eOi4j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LlXuA8Yz, 0, m, &cVar_LlXuA8Yz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K00DKf2R, 0, m, &cVar_K00DKf2R_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0pDF8R2L, 0, m, &cVar_0pDF8R2L_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_h7xfPepr, 0, m, &cVar_h7xfPepr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GsPFBawi, 0, m, &cVar_GsPFBawi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yvLhRkzV, 0, m, &cVar_yvLhRkzV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FP4Chxaf, 0, m, &cVar_FP4Chxaf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ccOiNUBO, 0, m, &cVar_ccOiNUBO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RkZzwcsi, 0, m, &cVar_RkZzwcsi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ELX8H5tX, 0, m, &cVar_ELX8H5tX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ff9gBaHX, 0, m, &cVar_Ff9gBaHX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ecbia8Pv, 0, m, &cVar_ecbia8Pv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_afYPBMtv, 0, m, &cVar_afYPBMtv_sendMessage);
  cMsg_YKOi6Gqn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oQ8z2yMz, 0, m, &cVar_oQ8z2yMz_sendMessage);
  cMsg_DQXy94WU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lRQOTshf, 0, m, &cVar_lRQOTshf_sendMessage);
  cMsg_MJznzCD2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hFIAMtKg, 0, m, &cVar_hFIAMtKg_sendMessage);
  cMsg_TUadr8r2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_yQZAMZMb, 0, m, &cVar_yQZAMZMb_sendMessage);
  cMsg_Fh59a9Ry_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vpOCKzAQ, 0, m, &cVar_vpOCKzAQ_sendMessage);
  cMsg_WkLa8b3t_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CBlHvbAM, 0, m, &cVar_CBlHvbAM_sendMessage);
  cMsg_Fs3SdUbO_sendMessage(_c, 0, m);
  cMsg_JDW0Viwo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gVAvyOWL, 0, m, &cVar_gVAvyOWL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oweIRwK3, 0, m, &cVar_oweIRwK3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uNquXJXk, 0, m, &cVar_uNquXJXk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wjvvtD3f, 0, m, &cVar_wjvvtD3f_sendMessage);
  cMsg_tZYTKT8s_sendMessage(_c, 0, m);
  cMsg_mKVEfAYh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_EuzTU5kA, 0, m, &cVar_EuzTU5kA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ah2Bzm6d, 0, m, &cVar_ah2Bzm6d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DgOouRHM, 0, m, &cVar_DgOouRHM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hpYIY4cT, 0, m, &cVar_hpYIY4cT_sendMessage);
  cMsg_GyOIumc5_sendMessage(_c, 0, m);
  cMsg_06UqpaYR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zYmdlLfs, 0, m, &cVar_zYmdlLfs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_24jZRmJ4, 0, m, &cVar_24jZRmJ4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_e7F8AU3M, 0, m, &cVar_e7F8AU3M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oPb15FdX, 0, m, &cVar_oPb15FdX_sendMessage);
  cMsg_KuZAsp95_sendMessage(_c, 0, m);
  cMsg_JkAlhsAq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KQG7ykps, 0, m, &cVar_KQG7ykps_sendMessage);
  cMsg_nc0jHXc1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jjuyIBuO, 0, m, &cVar_jjuyIBuO_sendMessage);
  cMsg_bl89GruV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Ws5nznNG, 0, m, &cVar_Ws5nznNG_sendMessage);
  cMsg_VpMJEaFh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JdcI1YcF, 0, m, &cVar_JdcI1YcF_sendMessage);
  cMsg_mlPSNWwB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eZRUIBDg, 0, m, &cVar_eZRUIBDg_sendMessage);
  cMsg_Q3x5GFMy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fFGDjsI5, 0, m, &cVar_fFGDjsI5_sendMessage);
  cMsg_S8Lbevro_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_R0mdhKRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ctELofF, HV_BINOP_MULTIPLY, 0, m, &cBinop_3ctELofF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_BAUPCgLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pQvJ4yvb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rnAea0Mc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_maFwtw3q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_fkrvg8FM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0RBq4W8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YGfT0u93_sendMessage);
  cMsg_EbHQLd94_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_uSM9uocJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OhPzjnif, HV_BINOP_MULTIPLY, 0, m, &cBinop_OhPzjnif_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SwN2TVsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_dkrG556b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XSR3B5Y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kxH7WFoN, HV_BINOP_MULTIPLY, 1, m, &cBinop_kxH7WFoN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iegNPGlR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fKVTlVtj_sendMessage);
  cMsg_PuLdSyd1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_9BmCqrge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_El9s3DCX, HV_BINOP_MULTIPLY, 0, m, &cBinop_El9s3DCX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LEm99LJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cz9YfRIo_sendMessage(_c, 0, m);
  cMsg_bPdyfKCH_sendMessage(_c, 0, m);
  cMsg_7DHqVzDL_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_52g27lAU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_anO72fYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xvgl7wNO_sendMessage);
  cMsg_OASrjX9b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_wGDEpUJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ERvjzQls, 0, m, &cVar_ERvjzQls_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ZKNbgZNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SxLFRTQv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OsnYKINb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xsTCBJ1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MRe0x8y2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hDd7dkWM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OgWcow4s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_joG2zovO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0vHG2roX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ka4PavS6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5osrV0Dj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ZxdvHYs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8bwkFZqV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QHy3RZqb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hrIF63ZU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6I5z6LSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3JdKKtUV, HV_BINOP_MULTIPLY, 0, m, &cBinop_3JdKKtUV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_CLg5Kunj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1oIVPDlL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rSA4bRR7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6QuakjNX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_tu2QD0t7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_hfG207lW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3YAqGUHz_sendMessage);
  cMsg_KS4ZzwQ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_Ki3etGhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jEc5WTkm, HV_BINOP_MULTIPLY, 0, m, &cBinop_jEc5WTkm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qolzBByd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_xqjxLinn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SxzSNtJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4mS1orc1, HV_BINOP_MULTIPLY, 1, m, &cBinop_4mS1orc1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CJA6tJx1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TRT8wIYr_sendMessage);
  cMsg_4XN5SYFW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_LsdbZyUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOA1MqsV, HV_BINOP_MULTIPLY, 0, m, &cBinop_bOA1MqsV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_K7WbD0ac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CDE1RavZ_sendMessage(_c, 0, m);
  cMsg_illfGxsd_sendMessage(_c, 0, m);
  cMsg_cVck3Ilb_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Xx48ScxV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Q4Lu4VNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4ClJXDQa_sendMessage);
  cMsg_GxoH9XPG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_p01iQsNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ngGNSCZL, 0, m, &cVar_ngGNSCZL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_f16dnZVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_yzZszgfk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_DHfxozQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_chjiaWZl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ZtcXzXzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6CHoxBj5, 0, m, &cVar_6CHoxBj5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_yBvra1eL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_SQaM1o59_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_pv3Qk4JK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_NzFwh6C3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_68jjmYb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_fe3qac3Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VP2TwDxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K8uNbnw3, 0, m, &cVar_K8uNbnw3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SPC7BNVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TUcVD3uv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_QseBfnp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_vJFaOaEO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_u82RfmiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_lknMjn4n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_8XolARBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LBDlD8pW, 0, m, &cVar_LBDlD8pW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_5dzVTMbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_SfsCBcaj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bcsud2vH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_Sm3FlKVn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_1BhqQXMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ALof5ntm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VRrN7hjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jZupi7Kc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_kE0Pr55n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_USy6vQNG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qOjseGfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_L56yK466_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_g6kRzX6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sogvUf8h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ORFojeBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_lpadRUry_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_101njFmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_6VbXPNbk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_gXjFMqpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_a2zC8L0a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_wBna76n8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_PKe3Y1vo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XhDCbGUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_AZJQvNHV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_V8wAMUmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sXw4zGXX_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_ZfhFo6jN, VOf(Bf0));
    __hv_line_f(&sLine_Bl4AXA1n, VOf(Bf1));
    __hv_line_f(&sLine_sIDkO21r, VOf(Bf2));
    __hv_line_f(&sLine_qfXxonEZ, VOf(Bf3));
    __hv_line_f(&sLine_YSdc7hoN, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_qKseYIBf, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_mPmOimLC, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_87ZJY5xQ, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_aX3IcceL, VOf(Bf1));
    __hv_line_f(&sLine_0gPOkgwn, VOf(Bf0));
    __hv_line_f(&sLine_6AqwVpLK, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_gmlbhYwd, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_mm7TNZRA, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_uBBiKLCN, VOf(Bf5));
    __hv_line_f(&sLine_xB5vVno0, VOf(Bf1));
    __hv_line_f(&sLine_pvldJ8Mm, VOf(Bf2));
    __hv_line_f(&sLine_swy87GB8, VOf(Bf4));
    __hv_line_f(&sLine_xSgZs37u, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_0xDrQ2X5, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_v0FRB8ij, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_Hy83DlQU, VOf(Bf6));
    __hv_line_f(&sLine_mJ1jJWDw, VOf(Bf2));
    __hv_line_f(&sLine_Bs4PUEm6, VOf(Bf1));
    __hv_line_f(&sLine_FxFRunxE, VOf(Bf5));
    __hv_line_f(&sLine_BFtO5Bf4, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_9b1OTnpN, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_XPuAdlsS, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Hcqo1PaB, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_0CPRdipH, VOf(Bf2));
    __hv_line_f(&sLine_i06P3QRt, VOf(Bf6));
    __hv_line_f(&sLine_nFlyuYqM, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_SNoQ1swU, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_dfvj6u83, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_qqkpIn1F, VOf(Bf8));
    __hv_line_f(&sLine_UDG2TRd8, VOf(Bf2));
    __hv_line_f(&sLine_WPQY1JXp, VOf(Bf1));
    __hv_line_f(&sLine_ZVN07b2L, VOf(Bf7));
    __hv_line_f(&sLine_wPcwuVhg, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_GH9jhsfh, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_cZsUDC5d, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_pPkQBfE5, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_YIKPUnKJ, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_6D6WFjID, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_qKUQPuyb, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_j4hLGAjg, VOf(Bf8));
    __hv_rpole_f(&sRPole_7NIEVmay, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_fNgdwJZ9, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_6ctDOYqq, VOf(Bf10));
    __hv_rpole_f(&sRPole_fX05wI8B, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_Pa10i9on, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_969NImFN, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_40RNGxya, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_eVTQZXAE, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_qLLU7Igh, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_PczK9kIV, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_uucwG5Vg, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_gHWjkpqU, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_Lhe2NSyj, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_WCbPafOI, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_eA6drEmr, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_UgvtKgnQ, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_6wVlKQAz, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_NWpG7kvh, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_X9hzn2TO, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_YoQHommw, VIf(Bf3));
    __hv_varwrite_f(&sVarf_4c0gpebP, VIf(Bf11));
    __hv_line_f(&sLine_D6Ko2NkM, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_eEr52Rvg, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_fZowTnW1, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_7Dntbjv6, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_RGrBiikX, VOf(Bf10));
    __hv_rpole_f(&sRPole_UnLcVBqj, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_bwGQBkaT, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_bM8FWsbd, VOf(Bf5));
    __hv_rpole_f(&sRPole_SKGGuLpU, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_GsbXUS1T, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_M9n5Kew2, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_9u2iFs9D, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_Z2LrQjgu, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_XOknnX1h, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_o4QrwVOe, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_xubY7vwP, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_eh6VIlIE, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_Bv9k39QX, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_Spn83Wkr, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_PPkfCQZE, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_2D3TnJ4k, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_JrHooztB, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_UZZ1XZZw, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_ztn4yq5p, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_usH4eFT3, VIf(Bf0));
    __hv_varwrite_f(&sVarf_TV1FH8i4, VIf(Bf8));
    __hv_line_f(&sLine_AbGIgxUB, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_YeZ3J0ZZ, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_d8JPLfdU, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_boVjYMgV, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_WMAdMGpt, VOf(Bf5));
    __hv_rpole_f(&sRPole_JHvQ8X8G, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_MWo5s6U8, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_RtNvuHLL, VOf(Bf6));
    __hv_rpole_f(&sRPole_ICDiRqi3, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_zbGW4Bbl, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_T8itcdB4, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_eHHgtdd6, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_EDNKlKaW, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_ZPJFgbpI, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_ox5KdVRV, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_BUvjM2kG, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_hrFzWVQr, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_pKK0T04r, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_H8nkLRH6, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_JlDaTDRE, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_AR8dadSy, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_M0knVvd5, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_2MPwhd00, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_cq9FxIhG, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_r6u4jebs, VIf(Bf4));
    __hv_varwrite_f(&sVarf_Aycd31VY, VIf(Bf10));
    __hv_varwrite_f(&sVarf_7VwNsx3U, VIf(Bf2));
    __hv_varwrite_f(&sVarf_7LdfaMOP, VIf(Bf9));
    __hv_varwrite_f(&sVarf_TQKl8qWC, VIf(Bf11));
    __hv_varread_f(&sVarf_7VwNsx3U, VOf(Bf11));
    __hv_varread_f(&sVarf_7LdfaMOP, VOf(Bf9));
    __hv_varread_f(&sVarf_TQKl8qWC, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_4c0gpebP, VOf(Bf2));
    __hv_varread_f(&sVarf_TV1FH8i4, VOf(Bf11));
    __hv_varread_f(&sVarf_Aycd31VY, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
